@@ -10,23 +10,24 @@ ETCDIR=${ETCDIR-/etc/temboard}
 VARDIR=${VARDIR-/var/lib/temboard}
 LOGDIR=${LOGDIR-/var/log/temboard}
 LOGFILE=${LOGFILE-/var/log/temboard-auto-configure.log}
+SYSUSER=${SYSUSER-temboard}
 
 
 catchall() {
 	local rc=$?
+	trap - INT EXIT TERM
 	set +x
 	if [ $rc -gt 0 ] ; then
 		fatal "Failure. See ${LOGFILE} for details."
 	else
-		rm -f ${LOGFILE}
+		rm -f "${LOGFILE}"
 	fi
 	exec 3>&-
-	trap - INT EXIT TERM
 }
 
 
 fatal() {
-	echo -e "\e[1;31m$@\e[0m" | tee -a /dev/fd/3 >&2
+	echo -e "\\e[1;31m$*\\e[0m" | tee -a /dev/fd/3 >&2
 	exit 1
 }
 
@@ -40,8 +41,8 @@ setup_logging() {
 	if [ -n "${DEBUG-}" ] ; then
 		exec 3>/dev/null
 	else
-		exec 3>&2 2>${LOGFILE} 1>&2
-		chmod 0600 ${LOGFILE}
+		exec 3>&2 2>"$LOGFILE" 1>&2
+		chmod 0600 "$LOGFILE"
 		trap 'catchall' INT EXIT TERM
 	fi
 
@@ -51,18 +52,21 @@ setup_logging() {
 
 
 setup_pq() {
+	local psql
+
 	# Ensure used libpq vars are defined for configuration template.
 
-	export PGHOST=${PGHOST-$(query_pgsettings unix_socket_directories)}
-	PGHOST=${PGHOST%%,*}
+	export PGHOST=${PGHOST-/var/run/postgresql}
 	export PGPORT=${PGPORT-5432}
 	export PGUSER=${PGUSER-postgres}
-	if [ -d ${PGHOST-/tmp} ] ; then
-		sudo="sudo -Eu ${PGUSER}"
+
+	if [ -d "$PGHOST" ] ; then
+		psql=(sudo -nEu "$PGUSER" psql)
 	else
-		sudo=
+		psql=(psql)
 	fi
-	if ! $sudo psql -tc "SELECT 'Postgres connection working.';" ; then
+
+	if ! "${psql[@]}" -tc "SELECT 'Postgres connection working.';" ; then
 		fatal "Can't connect to Postgres cluster."
 	fi
 }
@@ -80,29 +84,32 @@ setup_ssl() {
 		fatal "Failed to find PKI directory."
 	fi
 
-	if [ -f $pki/certs/ssl-cert-snakeoil.pem -a -f $pki/private/ssl-cert-snakeoil.key ] ; then
+	if [ -f $pki/certs/ssl-cert-snakeoil.pem ] && [ -f $pki/private/ssl-cert-snakeoil.key ] ; then
 		log "Using snake-oil SSL certificate."
 		sslcert=$pki/certs/ssl-cert-snakeoil.pem
 		sslkey=$pki/private/ssl-cert-snakeoil.key
 	else
-	     sslcert=$pki/certs/temboard.pem
-	     sslkey=$pki/private/temboard.key
-	     if ! [ -f $sslcert ] ; then
-		     log "Generating self-signed certificate."
-		     openssl req -new -x509 -days 365 -nodes \
-			     -subj "/C=XX/ST= /L=Default/O=Default/OU= /CN= " \
-			     -out $sslcert -keyout $sslkey
-		     chmod 644 $sslkey
-	     fi
+		sslcert=$pki/certs/temboard-auto.pem
+		sslkey=$pki/private/temboard-auto.key
+		if ! [ -f $sslcert ] ; then
+			log "Generating self-signed certificate."
+			openssl req -new -x509 -days 365 -nodes \
+				-subj "/C=XX/ST= /L=Default/O=Default/OU= /CN= " \
+				-out $sslcert -keyout $sslkey
+		fi
+		chmod 640 $sslkey
+		chgrp "$SYSUSER" "$sslkey"
 	fi
-	echo $sslcert $sslkey
+	readlink -e $sslcert $sslkey
 }
 
 
 generate_configuration() {
 	local sslcert=$1; shift
 	local sslkey=$1; shift
-	local cookiesecret="$(pwgen 128)"
+
+	sudo -iu "$SYSUSER" test -r "$sslcert"
+	sudo -iu "$SYSUSER" test -r "$sslkey"
 
 	cat <<-EOF
 	# Configuration initiated by $0 on $(date)
@@ -111,9 +118,10 @@ generate_configuration() {
 	# possibilities.
 
 	[temboard]
+	port = ${TEMBOARD_PORT-8888}
 	ssl_cert_file = $sslcert
 	ssl_key_file = $sslkey
-	cookie_secret = ${cookiesecret}
+	cookie_secret = $(pwgen 128)
 	home = ${VARDIR}
 
 	[repository]
@@ -121,14 +129,14 @@ generate_configuration() {
 	port = ${PGPORT}
 	user = temboard
 	password = ${TEMBOARD_PASSWORD}
-	dbname = temboard
+	dbname = ${TEMBOARD_DATABASE-temboard}
 
 	[logging]
 	method = stderr
-	level = INFO
+	level = ${TEMBOARD_LOGGING_LEVEL-INFO}
 
 	[monitoring]
-	# purge_after = 365
+	# purge_after = 730
 
 	[statements]
 	# purge_after = 7
@@ -144,51 +152,61 @@ pwgen() {
 
 #       M A I N
 
-cd $(readlink -m ${BASH_SOURCE[0]}/..)
+cd "$(readlink -m "${BASH_SOURCE[0]}/..")"
 
 setup_logging
 setup_pq
 
 export TEMBOARD_PASSWORD=${TEMBOARD_PASSWORD-$(pwgen)}
-if ! getent passwd temboard ; then
+if ! getent passwd "$SYSUSER" ; then
 	log "Creating system user temBoard."
 	useradd \
-		--system --user-group --shell /sbin/nologin \
-		--home-dir ${VARDIR} \
-		--comment "temBoard Web UI" temboard &>/dev/null
+		--system --user-group --shell "$SHELL" \
+		--home-dir "$VARDIR" \
+		--comment "temBoard Web UI" "$SYSUSER" &>/dev/null
 fi
 
-if getent group ssl-cert &>/dev/null; then
-	adduser temboard ssl-cert
+if getent group ssl-cert &>/dev/null && ! getent group ssl-cert | grep -q "$SYSUSER"; then
+	if command -v adduser &>/dev/null ; then
+		adduser "$SYSUSER" ssl-cert
+	else
+		fatal "$SYSUSER is not member of ssl-cert group and can't execute adduser. Make sure to add user in group before executing."
+	fi
 fi
 
 
 log "Configuring temboard in ${ETCDIR}."
-sslfiles=($(set -eu; setup_ssl))
-install -o temboard -g temboard -m 0750 -d ${ETCDIR} ${LOGDIR} ${VARDIR}
-install -o temboard -g temboard -m 0640 /dev/null ${ETCDIR}/temboard.conf
-generate_configuration "${sslfiles[@]}" > ${ETCDIR}/temboard.conf
+mapfile -t sslfiles < <(set -eu; setup_ssl)
+install -o "$SYSUSER" -g "$SYSUSER" -m 0750 -d "$ETCDIR" "$LOGDIR" "$VARDIR"
+install -o "$SYSUSER" -g "$SYSUSER" -m 0640 /dev/null "$ETCDIR/temboard.conf"
+generate_configuration "${sslfiles[@]}" > "$ETCDIR/temboard.conf"
 
 log "Creating Postgres user, database and schema."
-if [ -d ${PGHOST-/tmp} ] ; then
-	# If local, sudo to PGUSER.
-	sudo -Eu ${PGUSER} ./create_repository.sh
+# For temboard migratedb
+DEBUG=y TEMBOARD_CONFIGFILE="$ETCDIR/temboard.conf" ./create_repository.sh
+
+if [ "$(whoami)" != "$SYSUSER" ] ; then
+	# Run as temboard UNIX user. Wipe environment, this requires properly
+	# temboard.conf.
+	run_as_temboard=(sudo -Enu "$SYSUSER")
 else
-	./create_repository.sh
+	run_as_temboard=()
 fi
-dsn="postgres://temboard:${TEMBOARD_PASSWORD}@/temboard"
-if ! sudo -Eu temboard psql -Atc "SELECT 'CONNECTED';" "$dsn" | grep -q 'CONNECTED' ; then
+
+dsn="postgres://temboard:${TEMBOARD_PASSWORD}@/${TEMBOARD_DATABASE-temboard}"
+if ! "${run_as_temboard[@]}" psql -Atc "SELECT 'CONNECTED';" "$dsn" | grep -q 'CONNECTED' ; then
 	fatal "Can't configure access to Postgres database."
 fi
 
-if hash systemctl &>/dev/null; then
-	start_cmd="systemctl start temboard"
+TEMBOARD_CONFIGFILE="$ETCDIR/temboard.conf" "${run_as_temboard[@]}" temboard generate-key
+
+if grep -q systemd /proc/1/cmdline && [ -w /etc/systemd/system ] ; then
+	start_cmd="systemctl enable-now temboard"
 	if systemctl is-system-running &>/dev/null ; then
 		systemctl daemon-reload
-		systemctl enable temboard
 	fi
 else
-	start_cmd="temboard -c ${ETCDIR}/temboard.conf"
+	start_cmd="sudo -iu $SYSUSER temboard -c ${ETCDIR}/temboard.conf"
 fi
 
 log
