@@ -104,15 +104,6 @@ function load_update_user_form(modal_id, username)
 
       // Activate multiselect plugin for group selecting.
       $('#selectGroups').multiselect(multiselectOptions);
-      // Add group's description as a tooltip.
-      $('.multiselect-container li').not('.filter, .group').tooltip({
-          placement: 'right',
-          container: 'body',
-          title: function () {
-              var value = $(this).find('input').val();
-              return descriptions[value];
-          }
-      });
       // Use multiselect style for Active & Admin selects.
       $('#selectActive').multiselect(multiselectOptions);
       $('#selectAdmin').multiselect(multiselectOptions);
@@ -365,45 +356,6 @@ function send_add_user_form(modal_id)
   });
 }
 
-function sendEmail() {
-  $.ajax({
-    url: '/json/test_email',
-    type: 'post',
-    data: JSON.stringify({
-      email: $('#inputTestEmail').val()
-    }),
-    success: function(data) {
-      var msg = 'Test email successfully sent';
-      msg += '\nIf the email is not received, please have a look at your SMTP server logs';
-      alert(msg);
-    },
-    error: function(xhr) {
-      var msg = 'Mail could not be sent.';
-      if (xhr.responseText) {
-        msg += '\nError: ';
-        msg += escapeHtml(JSON.parse(xhr.responseText).error);
-      }
-      alert(msg);
-    }
-  });
-}
-
-function sendSms() {
-  $.ajax({
-    url: '/json/test_sms',
-    type: 'post',
-    data: JSON.stringify({
-      phone: $('#inputTestPhone').val()
-    }),
-    success: function(data) {
-      alert("Test SMS sent");
-    },
-    error: function(xhr) {
-      alert("SMS could not be sent.\nError: " + escapeHtml(JSON.parse(xhr.responseText).error));
-    }
-  });
-}
-
 var entityMap = {
   "&": "&amp;",
   "<": "&lt;",
