@@ -3,6 +3,7 @@
 
 import logging
 import os
+from argparse import SUPPRESS as SUPPRESS_ARG
 
 from .utils import DotDict
 from .errors import UserError
@@ -50,6 +51,20 @@ class OptionSpec(object):
     def required(self):
         return self.default is self.REQUIRED
 
+    def add_argument(self, parser, *a, **kw):
+        help_ = kw.get('help')
+        if help_:
+            help_ = help_ % dict(
+                default="*required*" if self.required else self.default,
+            )
+            # Escape % for Argparse formatting.
+            kw['help'] = help_.replace("%", "%%")
+
+        kw.setdefault('dest', str(self))
+        kw.setdefault('default', SUPPRESS_ARG)
+
+        return parser.add_argument(*a, **kw)
+
     def validate(self, value):
         if value.value is None or not self.validator:
             return value.value
@@ -86,6 +101,19 @@ def iter_configparser_values(parser, filename='config'):
     for section in parser.sections():
         for name, value in parser.items(section):
             name = '%s_%s' % (section, name)
+
+            if value.startswith('"') and value.startswith('"'):
+                raise UserError(
+                    "You must not quote string in configuration (%s)."
+                    % name.replace('_', '.')
+                )
+
+            if value.startswith("'") and value.startswith("'"):
+                raise UserError(
+                    "You must not quote string in configuration (%s)."
+                    % name.replace('_', '.')
+                )
+
             yield Value(name, value, origin=filename)
 
 
@@ -120,7 +148,7 @@ class MergedConfiguration(DotDict):
     # Origin order: args > environ > file > defaults
 
     def __init__(self, specs=None):
-        DotDict.__init__(self)
+        DotDict.__init__(self)  # PY2, move to super
         self.__dict__['specs'] = dict([(s, s) for s in specs or []])
         self.__dict__['unvalidated_specs'] = set(self.specs)
 
@@ -179,18 +207,37 @@ class MergedConfiguration(DotDict):
         try:
             self.add_values(iter_args_values(args))
             self.add_values(iter_environ_values(environ))
-            if parser:
-                # configfile values are relatives to configfile directory.
+        except ValueError as e:
+            logger.debug("Bad value %s.", e)
+            raise UserError("Failed to load configuration.")
+
+        if pwd:
+            try:
+                # configfile and default values are relative to configfile
+                # directory.
                 oldpwd = os.getcwd()
+            except OSError as e:
+                raise UserError("Failed to get CWD: %s" % e)
+
+            try:
                 os.chdir(pwd)
+            except OSError as e:
+                raise UserError("Failed to access %s: %s" % (pwd, e))
+        else:
+            oldpwd = None
+
+        try:
+            if parser:
                 self.add_values(iter_configparser_values(parser))
-                try:
-                    os.chdir(oldpwd)
-                except OSError as e:
-                    logger.debug("Can't move back to %s: %s", oldpwd, e)
             self.add_values(iter_defaults(self.specs))
         except ValueError as e:
             logger.debug("Bad value %s.", e)
             raise UserError("Failed to load configuration.")
 
+        if oldpwd:
+            try:
+                os.chdir(oldpwd)
+            except OSError as e:
+                logger.warning("Can't move back to %s: %s", oldpwd, e)
+
         self.check_required()
