@@ -1,19 +1,20 @@
-import re
 import sys
 from platform import python_version
 
 
-__version__ = "7.9"
+__version__ = "8.0"
 
 
+# This output is parsed by tests/conftest.py::pytest_report_header.
 VERSION_FMT = """\
-temBoard %(temboard)s
+temBoard %(temboard)s (%(temboardbin)s)
 System %(distname)s %(distversion)s
 Python %(python)s (%(pythonbin)s)
-psycopg2 %(psycopg2)s
+cryptography %(cryptography)s
 Tornado %(tornado)s
+libpq %(libpq)s
+psycopg2 %(psycopg2)s
 SQLAlchemy %(sqlalchemy)s
-alembic %(alembic)s
 """
 
 
@@ -22,35 +23,28 @@ def format_version():
 
 
 def inspect_versions():
-    from alembic import __version__ as alembic_version
+    from .toolkit.versions import (
+        format_pq_version,
+        read_distinfo,
+        read_libpq_version,
+    )
     from psycopg2 import __version__ as psycopg2_version
     from tornado import version as tornado_version
     from sqlalchemy import __version__ as sqlalchemy_version
+    import cryptography
 
-    with open('/etc/os-release') as fo:
-        distinfos = parse_lsb_release(fo)
+    distinfos = read_distinfo()
 
     return dict(
-        temboard=__version__,
-        alembic=alembic_version,
+        cryptography=cryptography.__version__,
+        distname=distinfos['NAME'],
+        distversion=distinfos.get('VERSION', 'n/a'),
+        libpq=format_pq_version(read_libpq_version()),
         psycopg2=psycopg2_version,
         python=python_version(),
         pythonbin=sys.executable,
-        tornado=tornado_version,
         sqlalchemy=sqlalchemy_version,
-        distname=distinfos['NAME'],
-        distversion=distinfos['VERSION'],
+        temboard=__version__,
+        temboardbin=sys.argv[0],
+        tornado=tornado_version,
     )
-
-
-def parse_lsb_release(lines):
-    _assignement_re = re.compile(
-        r"""(?P<variable>[A-Z_]+)="(?P<value>[^"]+)"$"""
-    )
-    infos = dict()
-    for line in lines:
-        m = _assignement_re.match(line)
-        if not m:
-            continue
-        infos[m.group('variable')] = m.group('value')
-    return infos
